@@ -226,6 +226,7 @@ dex_file_replace_cb (GObject      *object,
 
 /**
  * dex_file_replace:
+ * @etag: (nullable)
  *
  * Returns: (transfer full): a #DexFuture
  */
@@ -275,6 +276,8 @@ dex_input_stream_read_cb (GObject      *object,
 
 /**
  * dex_input_stream_read:
+ * @buffer: (array length=count) (element-type guint8) (out caller-allocates)
+ * @count: (in)
  *
  * Returns: (transfer full): a #DexFuture
  */
@@ -369,6 +372,7 @@ dex_output_stream_write_cb (GObject      *object,
 
 /**
  * dex_output_stream_write:
+ * @buffer: (array length=count) (element-type guint8)
  *
  * Returns: (transfer full): a #DexFuture
  */
@@ -1007,7 +1011,7 @@ dex_dbus_connection_send_message_with_reply_cb (GObject      *object,
  * @flags:  flags for @message
  * @timeout_msec: timeout in milliseconds, or -1 for default, or %G_MAXINT
  *   for no timeout.
- * @out_serial: (out) (nullable): a location for the message serial number
+ * @out_serial: (out) (optional): a location for the message serial number
  *
  * Wrapper for g_dbus_connection_send_message_with_reply().
  *
@@ -1063,12 +1067,12 @@ dex_dbus_connection_call_cb (GObject      *object,
 
 /**
  * dex_dbus_connection_call:
- * @bus_name:
+ * @bus_name: (nullable)
  * @object_path:
  * @interface_name:
  * @method_name:
- * @parameters:
- * @reply_type:
+ * @parameters: (nullable)
+ * @reply_type: (nullable)
  * @flags:
  * @timeout_msec:
  *
@@ -1155,12 +1159,12 @@ dex_dbus_connection_call_with_unix_fd_list_cb (GObject      *object,
 
 /**
  * dex_dbus_connection_call_with_unix_fd_list:
- * @bus_name:
+ * @bus_name: (nullable)
  * @object_path:
  * @interface_name:
  * @method_name:
- * @parameters:
- * @reply_type:
+ * @parameters: (nullable)
+ * @reply_type: (nullable)
  * @flags:
  * @timeout_msec:
  * @fd_list: (nullable): a #GUnixFDList
@@ -1308,3 +1312,53 @@ dex_subprocess_wait_check (GSubprocess *subprocess)
 
   return DEX_FUTURE (async_pair);
 }
+
+static void
+dex_file_query_exists_cb (GObject      *object,
+                          GAsyncResult *result,
+                          gpointer      user_data)
+{
+  DexPromise *promise = user_data;
+  GFileInfo *file_info;
+  GError *error = NULL;
+
+  file_info = g_file_query_info_finish (G_FILE (object), result, &error);
+
+  if (file_info != NULL)
+    dex_promise_resolve_boolean (promise, TRUE);
+  else
+    dex_promise_reject (promise, g_steal_pointer (&error));
+
+  g_clear_object (&file_info);
+
+  dex_unref (promise);
+}
+
+/**
+ * dex_file_query_exists:
+ * @file: a #GFile
+ *
+ * Queries to see if @file exists asynchronously.
+ *
+ * Returns: (transfer full): a #DexFuture that will resolve with %TRUE
+ *   if the file exists, otherwise reject with error.
+ *
+ * Since: 0.6
+ */
+DexFuture *
+dex_file_query_exists (GFile *file)
+{
+  DexPromise *promise;
+
+  g_return_val_if_fail (G_IS_FILE (file), NULL);
+
+  promise = dex_promise_new_cancellable ();
+  g_file_query_info_async (file,
+                           G_FILE_ATTRIBUTE_STANDARD_TYPE,
+                           G_FILE_QUERY_INFO_NONE,
+                           G_PRIORITY_DEFAULT,
+                           dex_promise_get_cancellable (promise),
+                           dex_file_query_exists_cb,
+                           dex_ref (promise));
+  return DEX_FUTURE (promise);
+}
